<?php
/**
 * Created by PhpStorm.
 * User: mbjacket81
 * Date: 9/11/17
 * Time: 1:13 AM
 */
class SD_Calendar_Widget extends WP_Widget {
	/**
	 * To create the example widget all four methods will be
	 * nested inside this single instance of the WP_Widget class.
	 **/

	public function __construct() {
		$widget_options = array(
			'classname' => 'sd_calendar_widget',
			'description' => 'A Widget for displaying the combined Google Calendar in a sidebar',
		);
		parent::__construct( 'sd_calendar_widget', 'Google Calendar Widget', $widget_options );
	}

	public function widget( $args, $instance ) {
		$title = apply_filters( 'widget_title', $instance[ 'title' ] );
		$calendarId = $instance['calendarId'];
		$calType = $instance["calType"];
		$lookahead = $instance["lookahead"];

		$blog_title = get_bloginfo( 'name' );
		$tagline = get_bloginfo( 'description' );
		echo $args['before_widget'] . $args['before_title'] . $title . $args['after_title'];

		if($calType == "agenda"){
			echo $this->getAgendaDisplay($calendarId, $lookahead);
		}else if($calType == "grid"){
			echo $this->getCalendarDisplay($calendarId);
		}
		?>

		<p><strong>Site Name:</strong> <?php echo $blog_title ?></p>
		<p><strong>Tagline:</strong> <?php echo $tagline ?></p>

		<?php echo $args['after_widget'];
	}

	public function form( $instance ) {
		$args = array(
			'post_type' => 'sd-google-calendars'
		);
		$post_query = new WP_Query($args);

		$title = ! empty( $instance['title'] ) ? $instance['title'] : '';
		$calendarId = !empty($instance['calendarId']) ? $instance['calendarId'] : '';
		$calType = ! empty( $instance['calType'] ) ? $instance['calType'] : '';
		$lookahead = ! empty( $instance['lookahead'] ) ? $instance['lookahead'] : '';

		$calendarMap = [];
		if($post_query->have_posts() ) {
			while ( $post_query->have_posts() ) {
				$post_query->the_post();
				$calendarMap[get_the_ID()] = get_the_title();
			}
		}
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">Title:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $title ); ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'calendarId' ); ?>">Calendar:</label>
			<select name="<?php echo $this->get_field_name( 'calendarId' ); ?>">
				<?php
				foreach($calendarMap as $key => $val){
					echo "<option value='".$key."' ".($key == $calendarId ? "selected" : "").">".$val."</option>";
				}
				?>
			</select>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'calType' ); ?>">Calendar Type:</label>
			<select name="<?php echo $this->get_field_name( 'calType' ); ?>">
				<option value="agenda" <?php echo ($calType == "agenda" ? "selected" : ""); ?>>Agenda</option>
				<option value="grid" <?php echo ($calType == "grid" ? "selected" : ""); ?>>Calendar Grid</option>
			</select>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'lookahead' ); ?>"># of Events to Display (*Agenda Type Only):</label>
			<input type="number" id="<?php echo $this->get_field_id( 'lookahead' ); ?>" name="<?php echo $this->get_field_name( 'lookahead' ); ?>" value="<?php echo !empty($lookahead) ? esc_attr( $lookahead ) : "5"; ?>" />
		</p>
		<?php
	}

	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance[ 'title' ] = strip_tags( $new_instance[ 'title' ] );
		$instance[ 'calendarId' ] = strip_tags( $new_instance[ 'calendarId' ] );
		$instance[ 'calType' ] = strip_tags( $new_instance[ 'calType' ] );
		$instance[ 'lookahead' ] = strip_tags( $new_instance[ 'lookahead' ] );
		return $instance;
	}

	public function getAgendaDisplay($calId, $lookahead){
		wp_register_script('prefix_moments', '//cdnjs.cloudflare.com/ajax/libs/moment.js/2.14.1/moment.min.js');
		wp_enqueue_script('prefix_moments');
		wp_register_script('calendar_monthly_script', SDGC_URL."/js/monthly.js");
		wp_enqueue_script('calendar_monthly_script');
		wp_register_script('calendar_tinycolor', SDGC_URL."/js/tinycolor.js");
		wp_enqueue_script('calendar_tinycolor');
		wp_enqueue_script('jquery', 'https://ajax.googleapis.com/ajax/libs/jquery/3.1.1/jquery.min.js', array('jquery'), '3.1.1', true);
		wp_register_script('prefix_bootstrap', '//maxcdn.bootstrapcdn.com/bootstrap/3.3.6/js/bootstrap.min.js');
		wp_enqueue_script('prefix_bootstrap');
		wp_register_style('prefix_bootstrap', '//maxcdn.bootstrapcdn.com/bootstrap/3.3.6/css/bootstrap.min.css');
		wp_enqueue_style('prefix_bootstrap');

		$post_fields_urls = unserialize( get_post_meta($calId, '_sdgc_calendar_urls', true) );
		$post_fields_color = unserialize( get_post_meta($calId, '_sdgc_calendar_color', true) );
		$urlColorMap = [];
		foreach($post_fields_urls as $key => $url){
			$urlColorMap[$url] = $post_fields_color[$key];
		}

		global $wpdb;
		$table_name = $wpdb->prefix . "sdgc_events";
		$results = $wpdb->get_results( $wpdb->prepare( "SELECT id,calendar,startdate,starttime,enddate,endtime,summary,description,location,map FROM {$table_name} where startdate >= CURDATE() and postid = %d order by startdate asc, time(starttime) asc limit {$lookahead}", $calId ), ARRAY_A );
		//DATE_FORMAT(starttime,"%h:%i %p")
		$output = "<ul class='sd-calendar-list'>";
		foreach ($results as $key => $res){
			$evtJSON = "{startDate: \"".$res["startdate"]."\", ".
			           "startTime: \"".date('g:i A', strtotime($res["starttime"]))."\", ".
			           "endDate: \"".$res["enddate"]."\",".
			           "endTime: \"".date('g:i A', strtotime($res["endtime"]))."\", ".
			           "title: \"".($res["summary"])."\", ".
			           "color: \"".$urlColorMap[$res["calendar"]]."\", ".
			           "id: ".$res["id"].", ".
			           "description: \"".($res["description"])."\", ".
			           "location: \"".($res["location"])."\", ".
			           "map: \"".$res["map"]."\"}";
			$startD = date("m/d/Y", strtotime($res["startdate"]));
			if ($key == 0){//} || isset($results[$key+1]) && $res["startdate"] != $results[$key+1]["startdate"]) {
				$output .= "<li>";
				$output .= "<span class='sd-date-text'>" . date("m/d/Y", strtotime($res["startdate"])) . "</span><br/>";
			}
			$output .= "<ul class='sd-date-events'>";//.date("m/d/Y", strtotime($res["startdate"])). "...".$results[$key+1]["startdate"];
			$output .= "<li><a href='#' id='agendaWidget".$res["id"]."' data-eventid='".$res["id"]."' onmouseover='return showPopoverWithEventAsJson(".$res["id"].",".$evtJSON.")'>";
			$output .= "<span class='sd-date-event-time'>".date('g:i A', strtotime($res["starttime"]))."</span>";
			if(!empty($res["summary"])) {
				$output .= "<span class='sd-date-event-title'>" . $res["summary"] . "</span>";
			}
			$output .= "</a></li>";
			$output .= "</ul>";
			if (isset($results[$key+1]) && $res["startdate"] != $results[$key+1]["startdate"]) {
				$output .= "</li><li>";
				$output .= "<span class='sd-date-text'>" . date("m/d/Y", strtotime($results[$key+1]["startdate"])) . "</span><br/>";
			}
			if (!isset($results[$key+1])) {
				$output .= "</li>";
			}
		}
		$output .= "</ul>";
		echo $output;
	}

	function getCalendarDisplay($postid){
		wp_register_script('prefix_bootstrap', '//maxcdn.bootstrapcdn.com/bootstrap/3.3.6/js/bootstrap.min.js');
		wp_enqueue_script('prefix_bootstrap');
		wp_register_style('prefix_bootstrap', '//maxcdn.bootstrapcdn.com/bootstrap/3.3.6/css/bootstrap.min.css');
		wp_enqueue_style('prefix_bootstrap');
		wp_register_script('prefix_moments', '//cdnjs.cloudflare.com/ajax/libs/moment.js/2.14.1/moment.min.js');
		wp_enqueue_script('prefix_moments');
		wp_register_style('calendar_monthly_style', SDGC_URL."/css/monthly.css");
		wp_enqueue_style('calendar_monthly_style');
		wp_register_script('calendar_monthly_script', SDGC_URL."/js/monthly.js");
		wp_enqueue_script('calendar_monthly_script');
		wp_register_script('calendar_tinycolor', SDGC_URL."/js/tinycolor.js");
		wp_enqueue_script('calendar_tinycolor');
		?>
		<div style="width:100%; display:inline-block;">
			<div class="monthly" id="mycalendarwidget"></div>
		</div>
		<script type="text/javascript">
        jQuery(document).ready( function($) {
            $('#mycalendarwidget').monthly({
                mode: 'event',
                xmlUrl: '<?php echo get_site_url()."/wp-admin/admin-ajax.php?action=sdgc_eventsxml_post&id=".$postid; ?>',
                showDescriptionModal: true
            });
            switch(window.location.protocol) {
                case 'http:':
                case 'https:':
                    // running on a server, should be good.
                    break;
                case 'file:':
                    alert('Just a heads-up, events will not work when run locally.');
            }
        });
		</script>
		<?php
	}

}


?>